/**
 * Error to be thrown if storage API is not supported by the device.
 * @public
 */
export declare const ErrNoStorageSupport: Error;
/**
 * Error to be thrown if requested key was not found in the storage.
 * @public
 */
export declare const ErrKeyNotFound: Error;
/**
 * The interface for local key-value storage.
 * @internal
 */
export interface Storage {
    /**
     * Retrieves a key from the storage.
     *
     * @param key - the key to retrieve
     */
    get(key: string): string | null;
    /**
     * Adds a key to the storage, possibly overwriting existing value.
     *
     * @param key - the key to write
     * @param val - the value to write
     */
    set(key: string, val: string): void;
    /**
     * Adds a key to the storage, possibly overwriting existing value.
     *
     * @param key - the key to write
     * @param genFn - generator function that will be invoked if the key cannot be found in the storage.
     * The return value of the function will be used as the value that will be stored under the given key.
     */
    getOrSet(key: string, genFn: () => string): string;
}
